summaryrefslogtreecommitdiff
path: root/compiler/ghci/ByteCodeGen.hs
diff options
context:
space:
mode:
authorGabor Greif <ggreif@gmail.com>2017-07-20 10:46:14 +0200
committerGabor Greif <ggreif@gmail.com>2017-07-20 10:47:47 +0200
commita273c735ca268988ee1550c248ba88b57a227cb9 (patch)
tree29cc527b94f2f6efcf4343659ba7234fec0a1dd2 /compiler/ghci/ByteCodeGen.hs
parentcc839c57ff9c80b50d39e8e2e66a18674bab3486 (diff)
downloadhaskell-a273c735ca268988ee1550c248ba88b57a227cb9.tar.gz
Spelling fixes
Diffstat (limited to 'compiler/ghci/ByteCodeGen.hs')
-rw-r--r--compiler/ghci/ByteCodeGen.hs8
1 files changed, 4 insertions, 4 deletions
diff --git a/compiler/ghci/ByteCodeGen.hs b/compiler/ghci/ByteCodeGen.hs
index 5c236f3dab..2695a98f9e 100644
--- a/compiler/ghci/ByteCodeGen.hs
+++ b/compiler/ghci/ByteCodeGen.hs
@@ -409,14 +409,14 @@ getVarOffSets depth env = catMaybes . map getOffSet
Nothing -> Nothing
Just offset ->
-- michalt: I'm not entirely sure why we need the stack
- -- adjustement by 2 here. I initially thought that there's
+ -- adjustment by 2 here. I initially thought that there's
-- something off with getIdValFromApStack (the only user of this
-- value), but it looks ok to me. My current hypothesis is that
- -- this "adjustement" is needed due to stack manipulation for
+ -- this "adjustment" is needed due to stack manipulation for
-- BRK_FUN in Interpreter.c In any case, this is used only when
-- we trigger a breakpoint.
- let adjustement = 2
- in Just (id, trunc16 $ depth - offset + adjustement)
+ let adjustment = 2
+ in Just (id, trunc16 $ depth - offset + adjustment)
trunc16 :: Word -> Word16
trunc16 w